@@ -186,6 +186,37 @@ combine.rwl(ca533, co021)
 
 
 
+cleanEx()
+nameEx("common.interval")
+### * common.interval
+
+flush(stderr()); flush(stdout())
+
+### Name: common.interval
+### Title: Common Interval
+### Aliases: common.interval
+### Keywords: manip
+
+### ** Examples
+
+data(co021)
+co021.s <- common.interval(co021, type="series", make.plot=TRUE)
+co021.y <- common.interval(co021, type="years", make.plot=TRUE)
+co021.b <- common.interval(co021, type="both", make.plot=TRUE)
+
+dim(co021)
+dim.s <- dim(co021.s)
+dim.s       # the highest number of series
+prod(dim.s) #   (33 series x 288 years = 9504)
+dim.y <- dim(co021.y)
+dim.y       # the highest number of years
+prod(dim.y) #   (27 series x 458 years = 12366)
+dim.b <- dim(co021.b)
+dim.b       # compromise solution
+prod(dim.b) #   (28 series x 435 years = 12180)
+
+
+
 cleanEx()
 nameEx("corr.rwl.seg")
 ### * corr.rwl.seg
@@ -351,6 +382,44 @@ legend("topright",
 
 
 
+cleanEx()
+nameEx("fill.internal.NA")
+### * fill.internal.NA
+
+flush(stderr()); flush(stdout())
+
+### Name: fill.internal.NA
+### Title: Fill Internal NA
+### Aliases: fill.internal.NA
+### Keywords: manip
+
+### ** Examples
+
+foo <- data.frame(x1=c(rnorm(5), NA, NA, rnorm(3)),
+                  x2=c(rnorm(10)),
+                  x3=c(NA, NA, rnorm(3), NA, rnorm(4)),
+                  x4=c(NA, NA, rnorm(3), NA, rnorm(3), NA),
+                  x5=c(NA, NA, rnorm(8)),
+                  x6=c(NA, rnorm(9)),
+                  x7=c(NA, rnorm(5), NA, rnorm(3)),
+                  x8=c(rnorm(8), NA, NA),
+                  x9=c(rnorm(5), NA, rnorm(3), NA))
+row.names(foo) <- 1901:1910
+
+fill.internal.NA(foo, fill=0)
+
+bar <- fill.internal.NA(foo, fill="Spline")
+baz <- fill.internal.NA(foo, fill="Linear")
+
+## note differences in method "Spline" vs. "Linear"
+yrs <- as.numeric(row.names(foo))
+plot(yrs, foo$x7, type="b", lwd=3)
+lines(yrs, bar$x7, col="red", lwd=2)
+lines(yrs, baz$x7, col="green", lwd=1)
+
+
+
+
 cleanEx()
 nameEx("gini.coef")
 ### * gini.coef
@@ -377,7 +446,7 @@ nameEx("glk")
 flush(stderr()); flush(stdout())
 
 ### Name: glk
-### Title: Calculate Gleichlaeufigkeit
+### Title: Calculate Gleichläufigkeit
 ### Aliases: glk
 ### Keywords: ts
 
@@ -456,6 +525,23 @@ flush(stderr()); flush(stdout())
 
 
 
+cleanEx()
+nameEx("pointer")
+### * pointer
+
+flush(stderr()); flush(stdout())
+
+### Name: pointer
+### Title: Calculates Pointer Years from a Group of Ring-Width Series
+### Aliases: pointer
+
+### ** Examples
+## Pointer years calculation on ring-width series. Returns a data.frame.
+data(gp.rwl)
+pointer(rwl=gp.rwl, rgv.thresh=10, nseries.thresh=75, round.decimals=2)
+
+
+
 cleanEx()
 nameEx("powt")
 ### * powt
